==> haskell-shell-escape-0.2.0-276-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-shell-escape.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 shell-escape
version:              0.2.0
visibility:           public
id:                   shell-escape-0.2.0-88NNh6Y5GYzEjbk97K3ALX
key:                  shell-escape-0.2.0-88NNh6Y5GYzEjbk97K3ALX
license:              BSD-3-Clause
maintainer:           oss@solidsnack.be
author:               Jason Dusek
homepage:             http://github.com/solidsnack/shell-escape
synopsis:             Shell escaping library.
description:
    Shell escaping library, offering both Bourne shell and Bash style escaping
    of ByteStrings.

category:             Text
abi:                  ad4191236dcad8a8ddbeb9ce1b6129f2
exposed:              True
exposed-modules:      Data.ByteString.ShellEscape Text.ShellEscape
hidden-modules:
    Data.ByteString.ShellEscape.Escape
    Data.ByteString.ShellEscape.EscapeVector
    Data.ByteString.ShellEscape.Sh Data.ByteString.ShellEscape.Bash
    Data.ByteString.ShellEscape.Put

import-dirs:          /usr/lib/ghc-9.4.8/site-local/shell-escape-0.2.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/shell-escape-0.2.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/shell-escape-0.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-shell-escape
hs-libraries:         HSshell-escape-0.2.0-88NNh6Y5GYzEjbk97K3ALX
depends:
    base-4.17.2.1 binary-0.8.9.1 bytestring-0.11.5.3 containers-0.6.7
    vector-0.13.2.0-BnQJYTBpbJKJ2sldbPuyJj

haddock-interfaces:
    /usr/share/doc/haskell-shell-escape/html/shell-escape.haddock

haddock-html:         /usr/share/doc/haskell-shell-escape/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-shell-escape-0.2.0-277-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-shell-escape.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 shell-escape
version:              0.2.0
visibility:           public
id:                   shell-escape-0.2.0-iBv5zyOVhlBKRf9sWEIhQ
key:                  shell-escape-0.2.0-iBv5zyOVhlBKRf9sWEIhQ
license:              BSD-3-Clause
maintainer:           oss@solidsnack.be
author:               Jason Dusek
homepage:             http://github.com/solidsnack/shell-escape
synopsis:             Shell escaping library.
description:
    Shell escaping library, offering both Bourne shell and Bash style escaping
    of ByteStrings.

category:             Text
abi:                  987ad35572866309d0ece949bf4993c5
exposed:              True
exposed-modules:      Data.ByteString.ShellEscape Text.ShellEscape
hidden-modules:
    Data.ByteString.ShellEscape.Escape
    Data.ByteString.ShellEscape.EscapeVector
    Data.ByteString.ShellEscape.Sh Data.ByteString.ShellEscape.Bash
    Data.ByteString.ShellEscape.Put

import-dirs:          /usr/lib/ghc-9.4.8/site-local/shell-escape-0.2.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/shell-escape-0.2.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/shell-escape-0.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-shell-escape
hs-libraries:         HSshell-escape-0.2.0-iBv5zyOVhlBKRf9sWEIhQ
depends:
    base-4.17.2.1 binary-0.8.9.1 bytestring-0.11.5.3 containers-0.6.7
    vector-0.13.2.0-7jLyylqham1Ij3AknS5IxU

haddock-interfaces:
    /usr/share/doc/haskell-shell-escape/html/shell-escape.haddock

haddock-html:         /usr/share/doc/haskell-shell-escape/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
